@@ -2,7 +2,7 @@ import itertools
 import logging
 import warnings
 from functools import partial
-from typing import Iterator
+from typing import Iterator, Union
 
 from requests import RequestException
 from requests_html import HTMLSession
@@ -48,7 +48,7 @@ class FacebookScraper:
         iter_pages_fn = partial(iter_pages, account=account, request_fn=self.get)
         return self._generic_get_posts(extract_post, iter_pages_fn, **kwargs)
 
-    def get_group_posts(self, group: str, **kwargs) -> Iterator[Post]:
+    def get_group_posts(self, group: Union[str, int], **kwargs) -> Iterator[Post]:
         iter_pages_fn = partial(iter_group_pages, group=group, request_fn=self.get)
         return self._generic_get_posts(extract_group_post, iter_pages_fn, **kwargs)
 
