@@ -2,7 +2,7 @@ import json
 import logging
 import re
 import textwrap
-from typing import Iterator, Optional
+from typing import Iterator, Optional, Union
 
 from . import utils
 from .constants import FB_MOBILE_BASE_URL
@@ -13,11 +13,11 @@ logger = logging.getLogger(__name__)
 
 
 def iter_pages(account: str, request_fn: RequestFunction) -> Iterator[Page]:
-    start_url = utils.urljoin(FB_MOBILE_BASE_URL, f'/{account}/posts/')
+    start_url = utils.urljoin(FB_MOBILE_BASE_URL, f'/{account}/')
     return generic_iter_pages(start_url, PageParser, request_fn)
 
 
-def iter_group_pages(group: str, request_fn: RequestFunction) -> Iterator[Page]:
+def iter_group_pages(group: Union[str, int], request_fn: RequestFunction) -> Iterator[Page]:
     start_url = utils.urljoin(FB_MOBILE_BASE_URL, f'groups/{group}/')
     return generic_iter_pages(start_url, GroupPageParser, request_fn)
 
